@@ -14,9 +14,9 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202003'
+__version__ = '2.202102'
 __dhlib__ = '/usr/share/debhelper/dh_make'
-policy_version = '4.5.1'
+policy_version = '4.6.0'
 
 
 def check_dhlib_path():
@@ -262,7 +262,7 @@ class License(Enum):
     isc = 'isc'
     lgpl2 = 'lgpl2'
     lgpl3 = 'lgpl3'
-    mit = 'mit'
+    expat = 'expat'
     custom = 'c'
     blank = ''
 
@@ -274,7 +274,7 @@ class License(Enum):
         matches = {'apache': cls.apache, 'artistic': cls.artistic,
                    'bsd': cls.bsd, 'gpl': cls.gpl2, 'gpl2': cls.gpl2,
                    'gpl3': cls.gpl3, 'isc': cls.isc, 'lgpl': cls.lgpl2,
-                   'lgpl2': cls.lgpl2, 'lgpl3': cls.lgpl3, 'mit': cls.mit}
+                   'lgpl2': cls.lgpl2, 'lgpl3': cls.lgpl3, 'expat': cls.expat}
         if args.copyright == 'custom':
             if args.copyrightfile is None:
                 sys.stderr.write(
@@ -299,14 +299,14 @@ class License(Enum):
 version_string = '''
 dh_make version {}
 
-Copyright (C) 1998-2020 Craig Small <csmall@debian.org>
+Copyright (C) 1998-2021 Craig Small <csmall@debian.org>
 Based on deb-make by Christoph Lameter <clameter@debian.org>.
 Custom template support by Bruce Sass <bmsass@shaw.ca>.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 '''.format(__version__)
 copyright_choices = ('apache', 'artistic', 'bsd', 'gpl', 'gpl2', 'gpl3',
-                     'isc', 'lgpl', 'lgpl2', 'lgpl3', 'mit', 'custom')
+                     'isc', 'lgpl', 'lgpl2', 'lgpl3', 'expat', 'custom')
 parser = argparse.ArgumentParser(
         prog="dh_make",
         formatter_class=argparse.RawTextHelpFormatter,
@@ -317,7 +317,7 @@ parser.add_argument('-c', '--copyright', metavar='<type>',
                     choices=copyright_choices,
                     help='use <type> of license in copyright file '
                     '(apache|artistic|bsd|gpl|gpl2|gpl3|isc|lgpl|lgpl2|'
-                    'lgpl3|mit|custom)')
+                    'lgpl3|expat|custom)')
 
 parser.add_argument('--copyrightfile', metavar='<file>',
                     help='Template to use for custom copyright')
